@@ -44,9 +44,10 @@ TESSDATA_EXTENSION = ".traineddata"
 
 __all__ = [
     'CharBoxBuilder',
+    'DigitBuilder'
     'get_available_builders',
     'get_available_languages',
-    'get_name'
+    'get_name',
     'get_version',
     'image_to_string',
     'is_available',
@@ -105,6 +106,21 @@ class CharBoxBuilder(object):
         return "Character boxes"
 
 
+class DigitBuilder(builders.TextBuilder):
+    """
+    If passed to image_to_string(), image_to_string() will return a string with only digits.
+    Characters recognition will consider text as if it will only composed by digits
+    """
+
+    @staticmethod
+    def __str__():
+        return "Digits only"
+
+    def __init__(self, tesseract_layout=3):
+        super(DigitBuilder, self).__init__(tesseract_layout)
+        self.tesseract_configs.append("digits")
+
+
 def get_name():
     return "Tesseract"
 
